function [year1,VarName2] = import_json(filename, startRow, endRow)
%IMPORTFILE Import numeric data from a text file as column vectors.
%   [YEAR1,VARNAME2] = IMPORTFILE(FILENAME) Reads data from text file
%   FILENAME for the default selection.
%
%   [YEAR1,VARNAME2] = IMPORTFILE(FILENAME, STARTROW, ENDROW) Reads data
%   from rows STARTROW through ENDROW of text file FILENAME.
%
% Example:
%   [year1,VarName2] = importfile('09-08-2016_32_0.json',2, 18);
%
%    See also TEXTSCAN.

% Auto-generated by MATLAB on 2016/08/09 17:16:41

%% Initialize variables.
delimiter = {',',':'};
if nargin<=2
    startRow = 2;
    endRow = 18;
end

%% Format string for each line of text:
%   column1: text (%q)
%	column2: double (%f)
% For more information, see the TEXTSCAN documentation.
formatSpec = '%q%f%[^\n\r]';

%% Open the text file.
fileID = fopen(filename,'r');

%% Read columns of data according to format string.
% This call is based on the structure of the file used to generate this
% code. If an error occurs for a different file, try regenerating the code
% from the Import Tool.
dataArray = textscan(fileID, formatSpec, endRow(1)-startRow(1)+1, 'Delimiter', delimiter, 'HeaderLines', startRow(1)-1, 'ReturnOnError', false);
for block=2:length(startRow)
    frewind(fileID);
    dataArrayBlock = textscan(fileID, formatSpec, endRow(block)-startRow(block)+1, 'Delimiter', delimiter, 'HeaderLines', startRow(block)-1, 'ReturnOnError', false);
    for col=1:length(dataArray)
        dataArray{col} = [dataArray{col};dataArrayBlock{col}];
    end
end

%% Close the text file.
fclose(fileID);

%% Post processing for unimportable data.
% No unimportable data rules were applied during the import, so no post
% processing code is included. To generate code which works for
% unimportable data, select unimportable cells in a file and regenerate the
% script.

%% Allocate imported array to column variable names
year1 = dataArray{:, 1};
VarName2 = dataArray{:, 2};


